@@ -137,9 +137,9 @@ arg_separator = ["COMMA", "CLOSING_PARENTHESIS"]
 
 
 class Context:
-    def __init__(self, filename, tokens, debug=0):
+    def __init__(self, filename, tokens, debug=0, added_value=[]):
         # File relative informations
-        self.filename = filename.split("/")[-1]
+        self.filename = filename
         self.filetype = filename.split(".")[-1]  # ?
         self.tokens = tokens
         self.debug = int(debug)
@@ -158,6 +158,7 @@ class Context:
 
         # Preprocessor handling
         self.preproc_scope_indent = 0
+        self.skip_define_error = True if added_value is not None and "CheckDefine" in added_value else False
 
     def peek_token(self, pos):
         return self.tokens[pos] if pos < len(self.tokens) else None
@@ -484,6 +485,9 @@ In \"{self.scope.name}\" from \
         nested_id = False
         identifier = None
         pointer = None
+        sizeof = False
+        if self.check_token(start - 1, "SIZEOF") is True:
+            sizeof = True
         i = self.skip_ws(i)
         while deep > 0:
             if self.check_token(i, "RPARENTHESIS"):
@@ -515,6 +519,8 @@ In \"{self.scope.name}\" from \
                 tmp = i + 1
                 if (identifier is not True and pointer == True) or ret_store is not None:
                     nested_id = True
+                if identifier is not True and self.check_token(tmp, "RPARENTHESIS") and self.scope.name == "Function" and deep == 1 and pointer == None and sizeof == False:
+                    return "cast", self.skip_nest(start)
                 identifier = True
                 tmp = self.skip_ws(tmp)
                 if pointer == True:
